This Elixir library provides a wrapper around the Python yfinance so that you can fetch stock price data from Yahoo! Finance®.
Setup
In order to run the underlying Python yfinance library, this library makes use of
Pythonx so that you can run Python
code inside your Elixir application. By default Yfinance will attempt to start
the Python runtime as part of application init, but if you attempt to start two
instances of Python Yfinance will assume that you have started it via
configuration.
If you do start Pythonx via your application configuration, simply make sure you add
the dependencies that this wrapper needs. Below is the default un_init that this
library uses for refernce:
[project]
name = "yfinance_ex"
version = "0.6.0"
requires-python = "==3.14.*"
dependencies = [
"yfinance>=1.2.0",
"polars>=1.39.0",
"pyarrow>=23.0.0"
]
Summary
Functions
This function returns the default Pythonx.uv_init toml definition.